nxp-pac

Crates

git

Versions

mcxa577

Flavors

Cpu0nstckcal

Struct Cpu0nstckcal 

#[repr(transparent)]
pub struct Cpu0nstckcal(pub u32);
Non-Secure CPU0 System Tick Calibration

Tuple Fields

0: u32

Implementations

Source

impl Cpu0nstckcal

pub const fn tenms(&self) -> u32

Reload value for 10 ms (100 Hz) timing, subject to system clock skew errors. If the value reads as zero, the calibration value is not known.

pub const fn set_tenms(&mut self, val: u32)

Reload value for 10 ms (100 Hz) timing, subject to system clock skew errors. If the value reads as zero, the calibration value is not known.

pub const fn skew(&self) -> Skew

Indicates whether the TENMS value is exact.

pub const fn set_skew(&mut self, val: Skew)

Indicates whether the TENMS value is exact.

pub const fn noref(&self) -> Noref

Indicates whether the device provides a reference clock to the processor.

pub const fn set_noref(&mut self, val: Noref)

Indicates whether the device provides a reference clock to the processor.