nxp-pac

Crates

git

Versions

mcxa577

Flavors

Nmisrc

Struct Nmisrc 

#[repr(transparent)]
pub struct Nmisrc(pub u32);
NMI Source Select

Tuple Fields

0: u32

Implementations

Source

impl Nmisrc

pub const fn irqcpu0(&self) -> u8

The IRQ number of the interrupt that acts as the Non-Maskable Interrupt (NMI) for CPU0, if enabled by NMIENCPU0.

pub const fn set_irqcpu0(&mut self, val: u8)

The IRQ number of the interrupt that acts as the Non-Maskable Interrupt (NMI) for CPU0, if enabled by NMIENCPU0.

pub const fn nmiencpu0(&self) -> bool

Enables the Non-Maskable Interrupt (NMI) source selected by IRQCPU0.

pub const fn set_nmiencpu0(&mut self, val: bool)

Enables the Non-Maskable Interrupt (NMI) source selected by IRQCPU0.