nxp-pac

Crates

git

Versions

mcxa577

Flavors

Remap

Struct Remap 

#[repr(transparent)]
pub struct Remap(pub u32);
AHB Matrix Remap Control

Tuple Fields

0: u32

Implementations

Source

impl Remap

pub const fn cpu0_sbus(&self) -> RemapCpu0Sbus

RAMX0 address remap for CPU System bus

pub const fn set_cpu0_sbus(&mut self, val: RemapCpu0Sbus)

RAMX0 address remap for CPU System bus

pub const fn smart_dma_i(&self) -> SmartDmaI

RAMX0 address remap for SmartDMA I-BUS

pub const fn set_smart_dma_i(&mut self, val: SmartDmaI)

RAMX0 address remap for SmartDMA I-BUS

pub const fn smart_dma_d(&self) -> SmartDmaD

RAMX0 address remap for SmartDMA D-BUS

pub const fn set_smart_dma_d(&mut self, val: SmartDmaD)

RAMX0 address remap for SmartDMA D-BUS

pub const fn dma0(&self) -> RemapDma0

RAMX0 address remap for DMA0

pub const fn set_dma0(&mut self, val: RemapDma0)

RAMX0 address remap for DMA0

pub const fn dma1(&self) -> RemapDma1

RAMX0 address remap for DMA1

pub const fn set_dma1(&mut self, val: RemapDma1)

RAMX0 address remap for DMA1

pub const fn pkc_els(&self) -> RemapPkcEls

RAMX0 address remap for PKC_ELS

pub const fn set_pkc_els(&mut self, val: RemapPkcEls)

RAMX0 address remap for PKC_ELS

pub const fn coolflux_y_espi(&self) -> RemapCoolfluxYEspi

RAMX0 address remap for ESPI

pub const fn set_coolflux_y_espi(&mut self, val: RemapCoolfluxYEspi)

RAMX0 address remap for ESPI

pub const fn usb_fs_enet(&self) -> RemapUsbFsEnet

RAMX0 address remap for ENET

pub const fn set_usb_fs_enet(&mut self, val: RemapUsbFsEnet)

RAMX0 address remap for ENET

pub const fn usb_hs(&self) -> RemapUsbHs

RAMX0 address remap for USB-HS

pub const fn set_usb_hs(&mut self, val: RemapUsbHs)

RAMX0 address remap for USB-HS

pub const fn lock(&self) -> RemapLock

This 1-bit field provides a mechanism to limit writes to this register to protect its contents. Once set, this bit remains asserted until a system reset.

pub const fn set_lock(&mut self, val: RemapLock)

This 1-bit field provides a mechanism to limit writes to this register to protect its contents. Once set, this bit remains asserted until a system reset.